@@ -1,6 +1,7 @@
 package Image::TextMode::Renderer::GD;
 
 use Moose;
+use Module::Runtime ();
 use GD;
 use Image::TextMode::Palette::ANSI;
 use Carp 'croak';
@@ -186,7 +187,7 @@ sub _prepare_options {
         my $class
             = 'Image::TextMode::' . ucfirst( $_ ) . q(::) . $options->{ $_ };
 
-        if ( !eval { Class::MOP::load_class( $class ) } ) {
+        if ( !eval { Module::Runtime::require_module( $class ) } ) {
             croak sprintf( "Unable to load ${_} '%s'", $options->{ $_ } );
         }
 
@@ -274,11 +275,11 @@ sub _render_frame {
 sub _font_to_gd {
     my ( $font, $options ) = @_;
     my $ninth = $options->{ '9th_bit' };
-    my $name = ( split( /\::/s, ref $font ) )[ -1 ];
+    my $name = lc( ( split( /\::/s, ref $font ) )[ -1 ] );
 
     if (my $fn = eval {
             File::ShareDir::dist_file( 'Image-TextMode',
-                lc $name . ( $ninth ? '_9b' : '' ) . '.fnt' );
+                $name . ( $ninth ? '_9b' : '' ) . '.fnt' );
         }
         )
     {
@@ -287,13 +288,22 @@ sub _font_to_gd {
 
     require File::Temp;
     my $temp = File::Temp->new;
+    _save_gd_font( $font, $options, $temp );
+    close $temp or croak "Unable to close temp file: $!";
 
-    binmode( $temp );
+    return GD::Font->load( $temp->filename );
+}
 
+sub _save_gd_font {
+    my ( $font, $options, $fh ) = @_;
+
+    binmode( $fh );
+
+    my $ninth     = $options->{ '9th_bit' };
     my $chars     = $font->chars;
     my $font_size = @$chars;
 
-    print $temp pack( 'VVVV',
+    print $fh pack( 'VVVV',
         $font_size, 0, $font->width + ( $ninth ? 1 : 0 ),
         $font->height );
 
@@ -308,12 +318,9 @@ sub _font_to_gd {
                         and $charval <= 0xdf ? $binary[ -1 ] : 0 );
             }
 
-            print $temp pack( 'C*', @binary );
+            print $fh pack( 'C*', @binary );
         }
     }
-    close $temp or croak "Unable to close temp file: $!";
-
-    return GD::Font->load( $temp->filename );
 }
 
 sub _fill_gd_palette {
